@@ -58,19 +58,16 @@ func (d dockerRuntime) Provision(ctx context.Context) error {
 		a.Add(d.useContext)
 	}
 
-	// validate docker socket access
-	a.Add(func() error {
-		return d.guest.RunQuiet("sh", "-c", "sudo chown ${USER} /var/run/docker.sock")
-	})
-
 	return a.Exec()
 }
 
 func (d dockerRuntime) Start(ctx context.Context) error {
 	a := d.Init(ctx)
 
-	a.Add(func() error {
-		return d.guest.Run("sudo", "service", "docker", "start")
+	// TODO: interval is high due to 0.6.3->0.6.4 docker-ce package transition
+	//       to ensure startup is successful
+	a.Retry("", time.Second*5, 24, func(int) error {
+		return d.guest.RunQuiet("sudo", "service", "docker", "start")
 	})
 
 	// service startup takes few seconds, retry at most 5 times before giving up.
